import shutil
import typing as t
from pathlib import Path

import typer
from jinja2 import Environment, FileSystemLoader, StrictUndefined
from rich import print
from simpleconf import Config

from makejinja.filters import filters
from makejinja.globals import globals

app = typer.Typer()


@app.command()
def run(
    input_folder: Path,
    output_folder: Path,
    pattern: str = "**/*",
    jinja_suffix: str = ".jinja",
    remove_jinja_suffix: bool = True,
    config: list[Path] = typer.Option([]),
    extensions: list[str] = typer.Option([]),
    lstrip_blocks: bool = True,
    trim_blocks: bool = True,
    keep_trailing_newline: bool = False,
    copy_tree: bool = True,
    skip_empty: bool = True,
):
    # Also consider env vars with `jinja_` prefix
    config_files: list[t.Union[str, Path]] = ["jinja.osenv"]

    for path in config:
        if path.is_dir():
            config_files.extend(
                file for file in path.iterdir() if not file.name.startswith(".")
            )
        elif path.is_file():
            config_files.append(path)

    data = Config.load(*config_files)

    env = Environment(
        loader=FileSystemLoader(input_folder),
        extensions=extensions,
        keep_trailing_newline=keep_trailing_newline,
        trim_blocks=trim_blocks,
        lstrip_blocks=lstrip_blocks,
    )
    env.filters.update(filters)
    env.globals.update(globals)

    if output_folder.is_dir():
        shutil.rmtree(output_folder)

    if copy_tree:
        shutil.copytree(input_folder, output_folder)

    output_folder.mkdir(parents=True, exist_ok=True)

    for input_path in input_folder.glob(pattern):
        if not input_path.is_dir():
            relative_path = input_path.relative_to(input_folder)
            output_path = output_folder / relative_path
            output_path.parent.mkdir(parents=True, exist_ok=True)

            if relative_path.suffix == jinja_suffix:
                template = env.get_template(str(relative_path))

                # Remove the copied file if the tree has been duplicated
                if copy_tree:
                    output_path.unlink()

                if remove_jinja_suffix:
                    output_path = output_path.with_suffix("")

                rendered = template.render(data)

                # Write the rendered template if it has content
                # Prevents empty macro definitions
                if rendered.strip() == "" and skip_empty:
                    print(f"Skip '{input_path}'")
                else:
                    print(f"Render '{input_path}'->'{output_path}'")
                    with output_path.open("w") as f:
                        f.write(rendered)

            elif not copy_tree:
                print(f"Copy '{input_path}'")
                shutil.copy2(input_path, output_path)


if __name__ == "__main__":
    app()



import typing as t
from urllib.parse import quote as urlparse


def hassurl(value: str) -> str:
    return urlparse(value).replace("_", "-")


filters: dict[str, t.Callable[[t.Any], t.Any]] = {"hassurl": hassurl}



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['makejinja']

package_data = \
{'': ['*']}

install_requires = \
['jinja2>=3.1.2,<4.0.0',
 'python-simpleconf[all]>=0.5.7,<0.6.0',
 'rich>=12.6.0,<13.0.0',
 'typer>=0.7.0,<0.8.0']

entry_points = \
{'console_scripts': ['makejinja = makejinja.cli:app']}

setup_kwargs = {
    'name': 'makejinja',
    'version': '0.4.1',
    'description': 'Automatically generate files based on Jinja templates. Use it to easily generate complex Home Assistant dashboards!',
    'long_description': '# MakeJinja\n',
    'author': 'Mirko Lenz',
    'author_email': 'mirko@mirkolenz.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/mirkolenz/makejinja',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



import typing as t


def getlang(
    value: t.Union[str, t.Mapping[str, t.Any]], lang: str, default_lang: str = "en"
):
    if isinstance(value, str):
        return value
    else:
        return value.get(lang, value.get(default_lang, ""))


globals: dict[str, t.Callable] = {"getlang": getlang}
